==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Output/alsa/translations/alsa_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Modulo ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>Informazioni sul modulo d&apos;uscita ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Modulo d&apos;uscita ALSA per Qmmp</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Impostazioni modulo ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="24"/>
        <source>Device Settings</source>
        <translation>Impostazione del device</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="36"/>
        <source>Audio device</source>
        <translation>Dispositivo audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Mixer</source>
        <translation>Mixer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="63"/>
        <source>Mixer card:</source>
        <translation>Scheda Mixer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="73"/>
        <source>Mixer device:</source>
        <translation>Dispositivo Mixer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="90"/>
        <source>Advanced Settings</source>
        <translation>Impostazoni avanzate</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="102"/>
        <source>Soundcard</source>
        <translation>Scheda audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="108"/>
        <source>Buffer time (ms):</source>
        <translation>Tempo di buffering (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="144"/>
        <source>Period time (ms):</source>
        <translation>Periodo (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="180"/>
        <source>Use mmap access</source>
        <translation>Usa accesso Mmap</translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Output/alsa/translations/alsa_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="33"/>
        <source>ALSA Plugin</source>
        <translation>Modulo ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>About ALSA Output Plugin</source>
        <translation>Informazioni sul modulo d&apos;uscita ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="59"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Modulo d&apos;uscita ALSA per Qmmp</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="60"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Impostazioni modulo ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Impostazione del device</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Dispositivo audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation>Mixer</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation>Scheda Mixer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation>Dispositivo Mixer:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation>Impostazoni avanzate</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation>Scheda audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation>Tempo di buffering (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation>Periodo (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation>Usa accesso Mmap</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Usa la funzione snd_pcm_pause</translation>
    </message>
</context>
</TS>
